# ModelS.tcl: generic input shell for use with all models
# Units: kip, in
# Kevin Mackie, 2001/02/01
# mackie@ce.berkeley.edu
#
# Takes ground motion and structural input parameters from higher
# level procedure and outputs data to files for computation of UCSD
# output quantities.  Performs static pushovers only.

proc ModelS {param_group directory skew L LoH fy fc rho_s DcDs ksoil wt rhos_trans deck abut ida} {

wipe

set gap_in 100
set g 386.4
set pi [expr acos(-1.0)]

# ------------------------------------------------------
# Perform the pushover analysis for yield condition data
# Load displacement only
# Longitudinal Direction only

source GenerateBridge.tcl
GenerateBridge $skew $L $LoH $fy $fc $rho_s $DcDs $ksoil $wt $rhos_trans $deck $gap_in $abut

set fstub [format "sl%04i" $param_group]

# Record top of column
recorder Node [format "%snd081.out" $fstub] disp -load -node 8  -dof 1
recorder Node [format "%snd082.out" $fstub] disp -load -node 8  -dof 2

# Record section deformations in columns
recorder Element 1 -file [format "%ssf011.out" $fstub] section 1 forces
recorder Element 1 -file [format "%ssd011.out" $fstub] section 1 deformations
recorder Element 1 -file [format "%ssf012.out" $fstub] section 2 forces
recorder Element 1 -file [format "%ssd012.out" $fstub] section 2 deformations
recorder Element 1 -file [format "%ssf013.out" $fstub] section 3 forces
recorder Element 1 -file [format "%ssd013.out" $fstub] section 3 deformations
recorder Element 1 -file [format "%ssf014.out" $fstub] section 4 forces
recorder Element 1 -file [format "%ssd014.out" $fstub] section 4 deformations
recorder Element 1 -file [format "%ssf015.out" $fstub] section 5 forces
recorder Element 1 -file [format "%ssd015.out" $fstub] section 5 deformations

# Record section deformations in left pile shafts
recorder Element 20 -file [format "%ssf201.out" $fstub] section 1 forces
recorder Element 20 -file [format "%ssd201.out" $fstub] section 1 deformations
recorder Element 20 -file [format "%ssf202.out" $fstub] section 2 forces
recorder Element 20 -file [format "%ssd202.out" $fstub] section 2 deformations
recorder Element 20 -file [format "%ssf203.out" $fstub] section 3 forces
recorder Element 20 -file [format "%ssd203.out" $fstub] section 3 deformations
recorder Element 20 -file [format "%ssf204.out" $fstub] section 4 forces
recorder Element 20 -file [format "%ssd204.out" $fstub] section 4 deformations

recorder Element 22 -file [format "%ssf221.out" $fstub] section 1 forces
recorder Element 22 -file [format "%ssd221.out" $fstub] section 1 deformations
recorder Element 22 -file [format "%ssf222.out" $fstub] section 2 forces
recorder Element 22 -file [format "%ssd222.out" $fstub] section 2 deformations
recorder Element 22 -file [format "%ssf223.out" $fstub] section 3 forces
recorder Element 22 -file [format "%ssd223.out" $fstub] section 3 deformations
recorder Element 22 -file [format "%ssf224.out" $fstub] section 4 forces
recorder Element 22 -file [format "%ssd224.out" $fstub] section 4 deformations

recorder Element 24 -file [format "%ssf241.out" $fstub] section 1 forces
recorder Element 24 -file [format "%ssd241.out" $fstub] section 1 deformations
recorder Element 24 -file [format "%ssf242.out" $fstub] section 2 forces
recorder Element 24 -file [format "%ssd242.out" $fstub] section 2 deformations
recorder Element 24 -file [format "%ssf243.out" $fstub] section 3 forces
recorder Element 24 -file [format "%ssd243.out" $fstub] section 3 deformations
recorder Element 24 -file [format "%ssf244.out" $fstub] section 4 forces
recorder Element 24 -file [format "%ssd244.out" $fstub] section 4 deformations

recorder Element 26 -file [format "%ssf261.out" $fstub] section 1 forces
recorder Element 26 -file [format "%ssd261.out" $fstub] section 1 deformations
recorder Element 26 -file [format "%ssf262.out" $fstub] section 2 forces
recorder Element 26 -file [format "%ssd262.out" $fstub] section 2 deformations
recorder Element 26 -file [format "%ssf263.out" $fstub] section 3 forces
recorder Element 26 -file [format "%ssd263.out" $fstub] section 3 deformations
recorder Element 26 -file [format "%ssf264.out" $fstub] section 4 forces
recorder Element 26 -file [format "%ssd264.out" $fstub] section 4 deformations

recorder Element 28 -file [format "%ssf281.out" $fstub] section 1 forces
recorder Element 28 -file [format "%ssd281.out" $fstub] section 1 deformations
recorder Element 28 -file [format "%ssf282.out" $fstub] section 2 forces
recorder Element 28 -file [format "%ssd282.out" $fstub] section 2 deformations
recorder Element 28 -file [format "%ssf283.out" $fstub] section 3 forces
recorder Element 28 -file [format "%ssd283.out" $fstub] section 3 deformations
recorder Element 28 -file [format "%ssf284.out" $fstub] section 4 forces
recorder Element 28 -file [format "%ssd284.out" $fstub] section 4 deformations

recorder Element 30 -file [format "%ssf301.out" $fstub] section 1 forces
recorder Element 30 -file [format "%ssd301.out" $fstub] section 1 deformations
recorder Element 30 -file [format "%ssf302.out" $fstub] section 2 forces
recorder Element 30 -file [format "%ssd302.out" $fstub] section 2 deformations
recorder Element 30 -file [format "%ssf303.out" $fstub] section 3 forces
recorder Element 30 -file [format "%ssd303.out" $fstub] section 3 deformations
recorder Element 30 -file [format "%ssf304.out" $fstub] section 4 forces
recorder Element 30 -file [format "%ssd304.out" $fstub] section 4 deformations

# Record deck movement at abutments
recorder Node [format "%snd031.out" $fstub] disp -load -node 3  -dof 1 2 3
recorder Node [format "%snd131.out" $fstub] disp -load -node 13 -dof 1 2 3

# Record left gap properties
#recorder Element 40 -file [format "%sef401.out" $fstub] forces
#recorder Element 40 -file [format "%sed401.out" $fstub] deformations
#recorder Element 41 -file [format "%sef411.out" $fstub] forces
#recorder Element 41 -file [format "%sed411.out" $fstub] deformations

# Record right gap properties
#recorder Element 42 -file [format "%sef421.out" $fstub] forces
#recorder Element 42 -file [format "%sed421.out" $fstub] deformations
#recorder Element 43 -file [format "%sef431.out" $fstub] forces
#recorder Element 43 -file [format "%sed431.out" $fstub] deformations

# Load control with variable load steps
#                     init Jd  min  max
integrator LoadControl  0   1   0    0

# Convergence test
#                  tolerance maxIter displayCode
test EnergyIncr     1.0e-12     15        0

# Solution algorithm
algorithm Newton

# DOF numberer
numberer RCM

# Constraint handler
constraints Plain

# System of equations solver
system BandGeneral

# Analysis for gravity load
analysis Static

# Perform the gravity load analysis
analyze 1

# Reference lateral loads
pattern Plain 5 Linear {
   #    node  FX   FY   FZ   MX   MY   MZ
   load   8   1.0  0.0  0.0  0.0  0.0  0.0
}

# Load control with variable load steps
#                       init  Jd   min   max
integrator LoadControl  10.0   3   5.0  10.0

# continue up linear path with load control
analysis Static
analyze 50

# change integrator for displacement monitoring
#	              	        node dof  dU1  Jd  minLam  maxLam
integrator DisplacementControl   8   1   0.1  3    0.05    0.1

# Perform the pushover analysis until failure
set static_slope 1000
set static_cnt 1

while { $static_slope > -0.1 && $static_cnt < 800 } {
   set res [analyze 1]
   if {$res < 0} {
      puts "Pushover analysis failed\n"
      set static_slope -10;
   }
   incr static_cnt
}

wipe

file delete [format "%ssf221.out" $fstub]
file delete [format "%ssd221.out" $fstub]
file delete [format "%ssf222.out" $fstub]
file delete [format "%ssd222.out" $fstub]
file delete [format "%ssf223.out" $fstub]
file delete [format "%ssd223.out" $fstub]
file delete [format "%ssf224.out" $fstub]
file delete [format "%ssd224.out" $fstub]
file delete [format "%ssf225.out" $fstub]
file delete [format "%ssd225.out" $fstub]

file delete [format "%ssf241.out" $fstub]
file delete [format "%ssd241.out" $fstub]
file delete [format "%ssf242.out" $fstub]
file delete [format "%ssd242.out" $fstub]
file delete [format "%ssf243.out" $fstub]
file delete [format "%ssd243.out" $fstub]
file delete [format "%ssf244.out" $fstub]
file delete [format "%ssd244.out" $fstub]
file delete [format "%ssf245.out" $fstub]
file delete [format "%ssd245.out" $fstub]

file delete [format "%ssf261.out" $fstub]
file delete [format "%ssd261.out" $fstub]
file delete [format "%ssf262.out" $fstub]
file delete [format "%ssd262.out" $fstub]
file delete [format "%ssf263.out" $fstub]
file delete [format "%ssd263.out" $fstub]
file delete [format "%ssf264.out" $fstub]
file delete [format "%ssd264.out" $fstub]
file delete [format "%ssf265.out" $fstub]
file delete [format "%ssd265.out" $fstub]

file delete [format "%ssf281.out" $fstub]
file delete [format "%ssd281.out" $fstub]
file delete [format "%ssf282.out" $fstub]
file delete [format "%ssd282.out" $fstub]
file delete [format "%ssf283.out" $fstub]
file delete [format "%ssd283.out" $fstub]
file delete [format "%ssf284.out" $fstub]
file delete [format "%ssd284.out" $fstub]
file delete [format "%ssf285.out" $fstub]
file delete [format "%ssd285.out" $fstub]

file delete [format "%ssf301.out" $fstub]
file delete [format "%ssd301.out" $fstub]
file delete [format "%ssf302.out" $fstub]
file delete [format "%ssd302.out" $fstub]
file delete [format "%ssf303.out" $fstub]
file delete [format "%ssd303.out" $fstub]
file delete [format "%ssf304.out" $fstub]
file delete [format "%ssd304.out" $fstub]
file delete [format "%ssf305.out" $fstub]
file delete [format "%ssd305.out" $fstub]

puts "Finished longitundinal pushover analysis..."

# end of longitudinal static pushover analysis
# ----------------------------------------------------------------------

# ------------------------------------------------------
# Perform the pushover analysis for yield condition data
# Transverse Direction only

wipe

source GenerateBridge.tcl
GenerateBridge $skew $L $LoH $fy $fc $rho_s $DcDs $ksoil $wt $rhos_trans $deck $gap_in $abut

set fstub [format "st%04i" $param_group]

# Record top of column
recorder Node [format "%snd081.out" $fstub] disp -load -node  8 -dof 1
recorder Node [format "%snd082.out" $fstub] disp -load -node  8 -dof 2

# Record deck movement at abutments
recorder Node [format "%snd031.out" $fstub] disp -load -node 3  -dof 1 2 3
recorder Node [format "%snd131.out" $fstub] disp -load -node 13 -dof 1 2 3

# Record section deformations in columns
recorder Element 1 -file [format "%ssf011.out" $fstub] section 1 forces
recorder Element 1 -file [format "%ssd011.out" $fstub] section 1 deformations
recorder Element 1 -file [format "%ssf015.out" $fstub] section 5 forces
recorder Element 1 -file [format "%ssd015.out" $fstub] section 5 deformations

# Record left gap properties
#recorder Element 40 -file [format "%sef401.out" $fstub] forces
#recorder Element 40 -file [format "%sed401.out" $fstub] deformations
#recorder Element 41 -file [format "%sef411.out" $fstub] forces
#recorder Element 41 -file [format "%sed411.out" $fstub] deformations

# Record right gap properties
#recorder Element 42 -file [format "%sef421.out" $fstub] forces
#recorder Element 42 -file [format "%sed421.out" $fstub] deformations
#recorder Element 43 -file [format "%sef431.out" $fstub] forces
#recorder Element 43 -file [format "%sed431.out" $fstub] deformations

# Use same integrator, test, algorithms, etc as longitudinal
#                     init Jd  min  max
integrator LoadControl  0   1   0    0

#                  tolerance maxIter displayCode
test EnergyIncr     1.0e-12     15        0
algorithm Newton
numberer RCM
constraints Plain
system SparseGeneral -piv
analysis Static
analyze 1

puts "done with gravity loads"

# Reference lateral loads
pattern Plain 5 Linear {
   #    node  FX   FY   FZ   MX   MY   MZ
   load   8   0.0  1.0  0.0  0.0  0.0  0.0
}

# Load control with variable load steps
#                       init  Jd   min   max
integrator LoadControl  10.0   3   5.0  10.0

# continue up linear path with load control
analysis Static
analyze 50

# change integrator for displacement monitoring
#		                   	   dlam1  Jd  minLam   maxLam
#		                   	        node dof  dU1  Jd  minLam  maxLam
integrator DisplacementControl   8   2   0.1  3    0.05    0.1

# Perform the pushover analysis under dynamic monitoring of failure
set static_slope 1000
set static_cnt 1

while { $static_slope > -0.1 && $static_cnt < 800 } {
   set res [analyze 1]
   if {$res < 0} {
      puts "Pushover analysis failed\n"
      set static_slope -10;
   }
   incr static_cnt
}

puts "Finished transverse pushover analysis..."

wipe

# end of transverse static pushover analysis
# ------------------------------------------------

source AnalysisS.tcl
AnalysisS $skew $L $LoH $fy $fc $rho_s $DcDs $ksoil $wt $rhos_trans $param_group

# ------------------------------------------------
# remove static recorder files to save space
# leave static files currently to check whether algorithm captured yield or not

set fstub [format "sl%04i" $param_group]
file delete [format "%snd031.out" $fstub]
file delete [format "%snd131.out" $fstub]
file delete [format "%snd081.out" $fstub]
file delete [format "%snd082.out" $fstub]

file delete [format "%ssd011.out" $fstub]
file delete [format "%ssd012.out" $fstub]
file delete [format "%ssd013.out" $fstub]
file delete [format "%ssd014.out" $fstub]
file delete [format "%ssd015.out" $fstub]
file delete [format "%ssf011.out" $fstub]
file delete [format "%ssf012.out" $fstub]
file delete [format "%ssf013.out" $fstub]
file delete [format "%ssf014.out" $fstub]
file delete [format "%ssf015.out" $fstub]

#file delete [format "%sef401.out" $fstub]
#file delete [format "%sed401.out" $fstub]
#file delete [format "%sef411.out" $fstub]
#file delete [format "%sed411.out" $fstub]
#file delete [format "%sef421.out" $fstub]
#file delete [format "%sed421.out" $fstub]
#file delete [format "%sef431.out" $fstub]
#file delete [format "%sed431.out" $fstub]

file delete [format "%sgd01.out" $fstub]
file delete [format "%sgf01.out" $fstub]

set fstub [format "st%04i" $param_group]
file delete [format "%snd031.out" $fstub]
file delete [format "%snd131.out" $fstub]
file delete [format "%snd081.out" $fstub]
file delete [format "%snd082.out" $fstub]

file delete [format "%ssd011.out" $fstub]
file delete [format "%ssd015.out" $fstub]
file delete [format "%ssf011.out" $fstub]
file delete [format "%ssf015.out" $fstub]

#file delete [format "%sef401.out" $fstub]
#file delete [format "%sed401.out" $fstub]
#file delete [format "%sef411.out" $fstub]
#file delete [format "%sed411.out" $fstub]
#file delete [format "%sef421.out" $fstub]
#file delete [format "%sed421.out" $fstub]
#file delete [format "%sef431.out" $fstub]
#file delete [format "%sed431.out" $fstub]
}
